@@ -18,4 +18,4 @@ def version():
     打印版本信息
     :return:
     """
-    print('DataFushion_Plugins_Python V1.0')
+    print('DataFushion_Plugins_Python V1.0.5')
